@@ -6,7 +6,7 @@
 namespace esphome {
 namespace ct_clamp {
 
-static const char *TAG = "ct_clamp";
+static const char *const TAG = "ct_clamp";
 
 void CTClampSensor::setup() {
   this->is_calibrating_offset_ = true;
@@ -64,6 +64,8 @@ void CTClampSensor::loop() {
 
   // Perform a single sample
   float value = this->source_->sample();
+  if (isnan(value))
+    return;
 
   if (this->is_calibrating_offset_) {
     this->sample_sum_ += value;
