@@ -4,7 +4,7 @@
 namespace esphome {
 namespace hmc5883l {
 
-static const char *TAG = "hmc5883l";
+static const char *const TAG = "hmc5883l";
 static const uint8_t HMC5883L_ADDRESS = 0x1E;
 static const uint8_t HMC5883L_REGISTER_CONFIG_A = 0x00;
 static const uint8_t HMC5883L_REGISTER_CONFIG_B = 0x01;
@@ -38,12 +38,9 @@ void HMC5883LComponent::setup() {
   }
 
   uint8_t config_a = 0;
-  // 0b0xx00000 << 5 Sample Averaging - 0b00=1 sample, 0b11=8 samples
-  config_a |= 0b01100000;
-  // 0b000xxx00 << 2 Data Output Rate - 0b100=15Hz
-  config_a |= 0b00010000;
-  // 0b000000xx << 0 Measurement Mode - 0b00=high impedance on load
-  config_a |= 0b00000000;
+  config_a |= this->oversampling_ << 5;
+  config_a |= this->datarate_ << 2;
+  config_a |= 0b0 << 0;  // Measurement Mode: Normal(high impedance on load)
   if (!this->write_byte(HMC5883L_REGISTER_CONFIG_A, config_a)) {
     this->error_code_ = COMMUNICATION_FAILED;
     this->mark_failed();
@@ -61,7 +58,6 @@ void HMC5883LComponent::setup() {
   uint8_t mode = 0;
   // Continuous Measurement Mode
   mode |= 0b00;
-
   if (!this->write_byte(HMC5883L_REGISTER_MODE, mode)) {
     this->error_code_ = COMMUNICATION_FAILED;
     this->mark_failed();
