@@ -8,6 +8,7 @@
 #include "esp_range_view.h"
 #include "light_output.h"
 #include "light_state.h"
+#include "transformers.h"
 
 #ifdef USE_POWER_SUPPLY
 #include "esphome/components/power_supply/power_supply.h"
@@ -16,7 +17,7 @@
 namespace esphome {
 namespace light {
 
-using ESPColor = Color;
+using ESPColor ESPDEPRECATED("esphome::light::ESPColor is deprecated, use esphome::Color instead.", "v1.21") = Color;
 
 class AddressableLight : public LightOutput, public Component {
  public:
@@ -53,9 +54,10 @@ class AddressableLight : public LightOutput, public Component {
   bool is_effect_active() const { return this->effect_active_; }
   void set_effect_active(bool effect_active) { this->effect_active_ = effect_active; }
   void write_state(LightState *state) override;
+  std::unique_ptr<LightTransformer> create_default_transition() override;
   void set_correction(float red, float green, float blue, float white = 1.0f) {
-    this->correction_.set_max_brightness(Color(uint8_t(roundf(red * 255.0f)), uint8_t(roundf(green * 255.0f)),
-                                               uint8_t(roundf(blue * 255.0f)), uint8_t(roundf(white * 255.0f))));
+    this->correction_.set_max_brightness(
+        Color(to_uint8_scale(red), to_uint8_scale(green), to_uint8_scale(blue), to_uint8_scale(white)));
   }
   void setup_state(LightState *state) override {
     this->correction_.calculate_gamma_table(state->get_gamma_correct());
@@ -70,6 +72,8 @@ class AddressableLight : public LightOutput, public Component {
   void call_setup() override;
 
  protected:
+  friend class AddressableLightTransformer;
+
   bool should_show_() const { return this->effect_active_ || this->next_show_; }
   void mark_shown_() {
     this->next_show_ = false;
@@ -92,6 +96,18 @@ class AddressableLight : public LightOutput, public Component {
   power_supply::PowerSupplyRequester power_;
 #endif
   LightState *state_parent_{nullptr};
+};
+
+class AddressableLightTransformer : public LightTransitionTransformer {
+ public:
+  AddressableLightTransformer(AddressableLight &light) : light_(light) {}
+
+  void start() override;
+  optional<LightColorValues> apply() override;
+
+ protected:
+  AddressableLight &light_;
+  Color target_color_{};
   float last_transition_progress_{0.0f};
   float accumulated_alpha_{0.0f};
 };
