@@ -27,6 +27,7 @@ template<typename... Ts> class LightControlAction : public Action<Ts...> {
  public:
   explicit LightControlAction(LightState *parent) : parent_(parent) {}
 
+  TEMPLATABLE_VALUE(ColorMode, color_mode)
   TEMPLATABLE_VALUE(bool, state)
   TEMPLATABLE_VALUE(uint32_t, transition_length)
   TEMPLATABLE_VALUE(uint32_t, flash_length)
@@ -37,10 +38,13 @@ template<typename... Ts> class LightControlAction : public Action<Ts...> {
   TEMPLATABLE_VALUE(float, blue)
   TEMPLATABLE_VALUE(float, white)
   TEMPLATABLE_VALUE(float, color_temperature)
+  TEMPLATABLE_VALUE(float, cold_white)
+  TEMPLATABLE_VALUE(float, warm_white)
   TEMPLATABLE_VALUE(std::string, effect)
 
   void play(Ts... x) override {
     auto call = this->parent_->make_call();
+    call.set_color_mode(this->color_mode_.optional_value(x...));
     call.set_state(this->state_.optional_value(x...));
     call.set_brightness(this->brightness_.optional_value(x...));
     call.set_color_brightness(this->color_brightness_.optional_value(x...));
@@ -49,6 +53,8 @@ template<typename... Ts> class LightControlAction : public Action<Ts...> {
     call.set_blue(this->blue_.optional_value(x...));
     call.set_white(this->white_.optional_value(x...));
     call.set_color_temperature(this->color_temperature_.optional_value(x...));
+    call.set_cold_white(this->cold_white_.optional_value(x...));
+    call.set_warm_white(this->warm_white_.optional_value(x...));
     call.set_effect(this->effect_.optional_value(x...));
     call.set_flash_length(this->flash_length_.optional_value(x...));
     call.set_transition_length(this->transition_length_.optional_value(x...));
@@ -135,39 +141,57 @@ class LightTurnOffTrigger : public Trigger<> {
   }
 };
 
+// This is slightly ugly, but we can't log in headers, and can't make this a static method on AddressableSet
+// due to the template. It's just a temporary warning anyway.
+void addressableset_warn_about_scale(const char *field);
+
 template<typename... Ts> class AddressableSet : public Action<Ts...> {
  public:
   explicit AddressableSet(LightState *parent) : parent_(parent) {}
 
   TEMPLATABLE_VALUE(int32_t, range_from)
   TEMPLATABLE_VALUE(int32_t, range_to)
-  TEMPLATABLE_VALUE(uint8_t, color_brightness)
-  TEMPLATABLE_VALUE(uint8_t, red)
-  TEMPLATABLE_VALUE(uint8_t, green)
-  TEMPLATABLE_VALUE(uint8_t, blue)
-  TEMPLATABLE_VALUE(uint8_t, white)
+  TEMPLATABLE_VALUE(float, color_brightness)
+  TEMPLATABLE_VALUE(float, red)
+  TEMPLATABLE_VALUE(float, green)
+  TEMPLATABLE_VALUE(float, blue)
+  TEMPLATABLE_VALUE(float, white)
 
   void play(Ts... x) override {
     auto *out = (AddressableLight *) this->parent_->get_output();
-    int32_t range_from = this->range_from_.value_or(x..., 0);
-    int32_t range_to = this->range_to_.value_or(x..., out->size() - 1) + 1;
-    uint8_t remote_color_brightness =
-        static_cast<uint8_t>(roundf(this->parent_->remote_values.get_color_brightness() * 255.0f));
-    uint8_t color_brightness = this->color_brightness_.value_or(x..., remote_color_brightness);
+    int32_t range_from = interpret_index(this->range_from_.value_or(x..., 0), out->size());
+    if (range_from < 0 || range_from >= out->size())
+      range_from = 0;
+
+    int32_t range_to = interpret_index(this->range_to_.value_or(x..., out->size() - 1) + 1, out->size());
+    if (range_to < 0 || range_to >= out->size())
+      range_to = out->size();
+
+    uint8_t color_brightness =
+        to_uint8_scale(this->color_brightness_.value_or(x..., this->parent_->remote_values.get_color_brightness()));
     auto range = out->range(range_from, range_to);
     if (this->red_.has_value())
-      range.set_red(esp_scale8(this->red_.value(x...), color_brightness));
+      range.set_red(esp_scale8(to_uint8_compat(this->red_.value(x...), "red"), color_brightness));
     if (this->green_.has_value())
-      range.set_green(esp_scale8(this->green_.value(x...), color_brightness));
+      range.set_green(esp_scale8(to_uint8_compat(this->green_.value(x...), "green"), color_brightness));
     if (this->blue_.has_value())
-      range.set_blue(esp_scale8(this->blue_.value(x...), color_brightness));
+      range.set_blue(esp_scale8(to_uint8_compat(this->blue_.value(x...), "blue"), color_brightness));
     if (this->white_.has_value())
-      range.set_white(this->white_.value(x...));
+      range.set_white(to_uint8_compat(this->white_.value(x...), "white"));
     out->schedule_show();
   }
 
  protected:
   LightState *parent_;
+
+  // Historically, this action required uint8_t (0-255) for RGBW values from lambdas. Keep compatibility.
+  static inline uint8_t to_uint8_compat(float value, const char *field) {
+    if (value > 1.0f) {
+      addressableset_warn_about_scale(field);
+      return static_cast<uint8_t>(value);
+    }
+    return to_uint8_scale(value);
+  }
 };
 
 }  // namespace light
