@@ -61,6 +61,9 @@ void MQTTSensorComponent::send_discovery(JsonObject &root, mqtt::SendDiscoveryCo
   if (this->sensor_->get_force_update())
     root["force_update"] = true;
 
+  if (this->sensor_->state_class == sensor::STATE_CLASS_MEASUREMENT)
+    root["state_class"] = "measurement";
+
   config.command_topic = false;
 }
 bool MQTTSensorComponent::send_initial_state() {
