@@ -11,7 +11,6 @@ from esphome.const import (
     CONF_RISING_EDGE,
     CONF_NUMBER,
     CONF_TOTAL,
-    DEVICE_CLASS_EMPTY,
     ICON_PULSE,
     STATE_CLASS_MEASUREMENT,
     STATE_CLASS_NONE,
@@ -67,11 +66,10 @@ def validate_count_mode(value):
 
 CONFIG_SCHEMA = (
     sensor.sensor_schema(
-        UNIT_PULSES_PER_MINUTE,
-        ICON_PULSE,
-        2,
-        DEVICE_CLASS_EMPTY,
-        STATE_CLASS_MEASUREMENT,
+        unit_of_measurement=UNIT_PULSES_PER_MINUTE,
+        icon=ICON_PULSE,
+        accuracy_decimals=2,
+        state_class=STATE_CLASS_MEASUREMENT,
     )
     .extend(
         {
@@ -94,7 +92,10 @@ CONFIG_SCHEMA = (
             ),
             cv.Optional(CONF_INTERNAL_FILTER, default="13us"): validate_internal_filter,
             cv.Optional(CONF_TOTAL): sensor.sensor_schema(
-                UNIT_PULSES, ICON_PULSE, 0, DEVICE_CLASS_EMPTY, STATE_CLASS_NONE
+                unit_of_measurement=UNIT_PULSES,
+                icon=ICON_PULSE,
+                accuracy_decimals=0,
+                state_class=STATE_CLASS_NONE,
             ),
         }
     )
