@@ -7,7 +7,7 @@ from esphome.const import (
     CONF_RESOLUTION,
     CONF_MIN_VALUE,
     CONF_MAX_VALUE,
-    DEVICE_CLASS_EMPTY,
+    STATE_CLASS_NONE,
     UNIT_STEPS,
     ICON_ROTATE_RIGHT,
     CONF_VALUE,
@@ -56,7 +56,12 @@ def validate_min_max_value(config):
 
 
 CONFIG_SCHEMA = cv.All(
-    sensor.sensor_schema(UNIT_STEPS, ICON_ROTATE_RIGHT, 0, DEVICE_CLASS_EMPTY)
+    sensor.sensor_schema(
+        unit_of_measurement=UNIT_STEPS,
+        icon=ICON_ROTATE_RIGHT,
+        accuracy_decimals=0,
+        state_class=STATE_CLASS_NONE,
+    )
     .extend(
         {
             cv.GenerateID(): cv.declare_id(RotaryEncoderSensor),
@@ -91,17 +96,17 @@ CONFIG_SCHEMA = cv.All(
 )
 
 
-def to_code(config):
+async def to_code(config):
     var = cg.new_Pvariable(config[CONF_ID])
-    yield cg.register_component(var, config)
-    yield sensor.register_sensor(var, config)
-    pin_a = yield cg.gpio_pin_expression(config[CONF_PIN_A])
+    await cg.register_component(var, config)
+    await sensor.register_sensor(var, config)
+    pin_a = await cg.gpio_pin_expression(config[CONF_PIN_A])
     cg.add(var.set_pin_a(pin_a))
-    pin_b = yield cg.gpio_pin_expression(config[CONF_PIN_B])
+    pin_b = await cg.gpio_pin_expression(config[CONF_PIN_B])
     cg.add(var.set_pin_b(pin_b))
 
     if CONF_PIN_RESET in config:
-        pin_i = yield cg.gpio_pin_expression(config[CONF_PIN_RESET])
+        pin_i = await cg.gpio_pin_expression(config[CONF_PIN_RESET])
         cg.add(var.set_reset_pin(pin_i))
     cg.add(var.set_resolution(config[CONF_RESOLUTION]))
     if CONF_MIN_VALUE in config:
@@ -111,10 +116,10 @@ def to_code(config):
 
     for conf in config.get(CONF_ON_CLOCKWISE, []):
         trigger = cg.new_Pvariable(conf[CONF_TRIGGER_ID], var)
-        yield automation.build_automation(trigger, [], conf)
+        await automation.build_automation(trigger, [], conf)
     for conf in config.get(CONF_ON_ANTICLOCKWISE, []):
         trigger = cg.new_Pvariable(conf[CONF_TRIGGER_ID], var)
-        yield automation.build_automation(trigger, [], conf)
+        await automation.build_automation(trigger, [], conf)
 
 
 @automation.register_action(
@@ -127,9 +132,9 @@ def to_code(config):
         }
     ),
 )
-def sensor_template_publish_to_code(config, action_id, template_arg, args):
-    paren = yield cg.get_variable(config[CONF_ID])
+async def sensor_template_publish_to_code(config, action_id, template_arg, args):
+    paren = await cg.get_variable(config[CONF_ID])
     var = cg.new_Pvariable(action_id, template_arg, paren)
-    template_ = yield cg.templatable(config[CONF_VALUE], args, int)
+    template_ = await cg.templatable(config[CONF_VALUE], args, int)
     cg.add(var.set_value(template_))
-    yield var
+    return var
