@@ -1,5 +1,4 @@
 import math
-from typing import Optional
 
 import esphome.codegen as cg
 import esphome.config_validation as cv
@@ -11,17 +10,20 @@ from esphome.const import (
     CONF_ACCURACY_DECIMALS,
     CONF_ALPHA,
     CONF_BELOW,
+    CONF_DISABLED_BY_DEFAULT,
     CONF_EXPIRE_AFTER,
     CONF_FILTERS,
     CONF_FROM,
     CONF_ICON,
     CONF_ID,
     CONF_INTERNAL,
+    CONF_LAST_RESET_TYPE,
     CONF_ON_RAW_VALUE,
     CONF_ON_VALUE,
     CONF_ON_VALUE_RANGE,
     CONF_SEND_EVERY,
     CONF_SEND_FIRST_AT,
+    CONF_STATE_CLASS,
     CONF_TO,
     CONF_TRIGGER_ID,
     CONF_UNIT_OF_MEASUREMENT,
@@ -29,14 +31,19 @@ from esphome.const import (
     CONF_NAME,
     CONF_MQTT_ID,
     CONF_FORCE_UPDATE,
-    UNIT_EMPTY,
-    ICON_EMPTY,
+    LAST_RESET_TYPE_AUTO,
+    LAST_RESET_TYPE_NEVER,
+    LAST_RESET_TYPE_NONE,
     DEVICE_CLASS_EMPTY,
     DEVICE_CLASS_BATTERY,
+    DEVICE_CLASS_CARBON_MONOXIDE,
+    DEVICE_CLASS_CARBON_DIOXIDE,
     DEVICE_CLASS_CURRENT,
     DEVICE_CLASS_ENERGY,
+    DEVICE_CLASS_GAS,
     DEVICE_CLASS_HUMIDITY,
     DEVICE_CLASS_ILLUMINANCE,
+    DEVICE_CLASS_MONETARY,
     DEVICE_CLASS_SIGNAL_STRENGTH,
     DEVICE_CLASS_TEMPERATURE,
     DEVICE_CLASS_POWER,
@@ -45,26 +52,48 @@ from esphome.const import (
     DEVICE_CLASS_TIMESTAMP,
     DEVICE_CLASS_VOLTAGE,
 )
-from esphome.core import CORE, coroutine, coroutine_with_priority
+from esphome.core import CORE, coroutine_with_priority
 from esphome.util import Registry
 
 CODEOWNERS = ["@esphome/core"]
 DEVICE_CLASSES = [
     DEVICE_CLASS_EMPTY,
     DEVICE_CLASS_BATTERY,
+    DEVICE_CLASS_CARBON_MONOXIDE,
+    DEVICE_CLASS_CARBON_DIOXIDE,
     DEVICE_CLASS_CURRENT,
     DEVICE_CLASS_ENERGY,
+    DEVICE_CLASS_GAS,
     DEVICE_CLASS_HUMIDITY,
     DEVICE_CLASS_ILLUMINANCE,
+    DEVICE_CLASS_MONETARY,
     DEVICE_CLASS_SIGNAL_STRENGTH,
     DEVICE_CLASS_TEMPERATURE,
+    DEVICE_CLASS_TIMESTAMP,
     DEVICE_CLASS_POWER,
     DEVICE_CLASS_POWER_FACTOR,
     DEVICE_CLASS_PRESSURE,
-    DEVICE_CLASS_TIMESTAMP,
     DEVICE_CLASS_VOLTAGE,
 ]
 
+sensor_ns = cg.esphome_ns.namespace("sensor")
+StateClasses = sensor_ns.enum("StateClass")
+STATE_CLASSES = {
+    "": StateClasses.STATE_CLASS_NONE,
+    "measurement": StateClasses.STATE_CLASS_MEASUREMENT,
+    "total_increasing": StateClasses.STATE_CLASS_TOTAL_INCREASING,
+}
+validate_state_class = cv.enum(STATE_CLASSES, lower=True, space="_")
+
+LastResetTypes = sensor_ns.enum("LastResetType")
+LAST_RESET_TYPES = {
+    LAST_RESET_TYPE_NONE: LastResetTypes.LAST_RESET_TYPE_NONE,
+    LAST_RESET_TYPE_NEVER: LastResetTypes.LAST_RESET_TYPE_NEVER,
+    LAST_RESET_TYPE_AUTO: LastResetTypes.LAST_RESET_TYPE_AUTO,
+}
+validate_last_reset_type = cv.enum(LAST_RESET_TYPES, lower=True, space="_")
+
+
 IS_PLATFORM_COMPONENT = True
 
 
@@ -140,19 +169,21 @@ CalibrateLinearFilter = sensor_ns.class_("CalibrateLinearFilter", Filter)
 CalibratePolynomialFilter = sensor_ns.class_("CalibratePolynomialFilter", Filter)
 SensorInRangeCondition = sensor_ns.class_("SensorInRangeCondition", Filter)
 
-unit_of_measurement = cv.string_strict
-accuracy_decimals = cv.int_
-icon = cv.icon
-device_class = cv.one_of(*DEVICE_CLASSES, lower=True, space="_")
+validate_unit_of_measurement = cv.string_strict
+validate_accuracy_decimals = cv.int_
+validate_icon = cv.icon
+validate_device_class = cv.one_of(*DEVICE_CLASSES, lower=True, space="_")
 
-SENSOR_SCHEMA = cv.MQTT_COMPONENT_SCHEMA.extend(
+SENSOR_SCHEMA = cv.NAMEABLE_SCHEMA.extend(cv.MQTT_COMPONENT_SCHEMA).extend(
     {
         cv.OnlyWith(CONF_MQTT_ID, "mqtt"): cv.declare_id(mqtt.MQTTSensorComponent),
         cv.GenerateID(): cv.declare_id(Sensor),
-        cv.Optional(CONF_UNIT_OF_MEASUREMENT): unit_of_measurement,
-        cv.Optional(CONF_ICON): icon,
-        cv.Optional(CONF_ACCURACY_DECIMALS): accuracy_decimals,
-        cv.Optional(CONF_DEVICE_CLASS): device_class,
+        cv.Optional(CONF_UNIT_OF_MEASUREMENT): validate_unit_of_measurement,
+        cv.Optional(CONF_ICON): validate_icon,
+        cv.Optional(CONF_ACCURACY_DECIMALS): validate_accuracy_decimals,
+        cv.Optional(CONF_DEVICE_CLASS): validate_device_class,
+        cv.Optional(CONF_STATE_CLASS): validate_state_class,
+        cv.Optional(CONF_LAST_RESET_TYPE): validate_last_reset_type,
         cv.Optional(CONF_FORCE_UPDATE, default=False): cv.boolean,
         cv.Optional(CONF_EXPIRE_AFTER): cv.All(
             cv.requires_component("mqtt"),
@@ -180,52 +211,72 @@ SENSOR_SCHEMA = cv.MQTT_COMPONENT_SCHEMA.extend(
     }
 )
 
+_UNDEF = object()
+
 
 def sensor_schema(
-    unit_of_measurement_: str,
-    icon_: str,
-    accuracy_decimals_: int,
-    device_class_: Optional[str] = DEVICE_CLASS_EMPTY,
+    unit_of_measurement: str = _UNDEF,
+    icon: str = _UNDEF,
+    accuracy_decimals: int = _UNDEF,
+    device_class: str = _UNDEF,
+    state_class: str = _UNDEF,
+    last_reset_type: str = _UNDEF,
 ) -> cv.Schema:
     schema = SENSOR_SCHEMA
-    if unit_of_measurement_ != UNIT_EMPTY:
+    if unit_of_measurement is not _UNDEF:
         schema = schema.extend(
             {
                 cv.Optional(
-                    CONF_UNIT_OF_MEASUREMENT, default=unit_of_measurement_
-                ): unit_of_measurement
+                    CONF_UNIT_OF_MEASUREMENT, default=unit_of_measurement
+                ): validate_unit_of_measurement
             }
         )
-    if icon_ != ICON_EMPTY:
-        schema = schema.extend({cv.Optional(CONF_ICON, default=icon_): icon})
-    if accuracy_decimals_ != 0:
+    if icon is not _UNDEF:
+        schema = schema.extend({cv.Optional(CONF_ICON, default=icon): validate_icon})
+    if accuracy_decimals is not _UNDEF:
         schema = schema.extend(
             {
                 cv.Optional(
-                    CONF_ACCURACY_DECIMALS, default=accuracy_decimals_
-                ): accuracy_decimals,
+                    CONF_ACCURACY_DECIMALS, default=accuracy_decimals
+                ): validate_accuracy_decimals,
             }
         )
-    if device_class_ != DEVICE_CLASS_EMPTY:
+    if device_class is not _UNDEF:
         schema = schema.extend(
-            {cv.Optional(CONF_DEVICE_CLASS, default=device_class_): device_class}
+            {
+                cv.Optional(
+                    CONF_DEVICE_CLASS, default=device_class
+                ): validate_device_class
+            }
+        )
+    if state_class is not _UNDEF:
+        schema = schema.extend(
+            {cv.Optional(CONF_STATE_CLASS, default=state_class): validate_state_class}
+        )
+    if last_reset_type is not _UNDEF:
+        schema = schema.extend(
+            {
+                cv.Optional(
+                    CONF_LAST_RESET_TYPE, default=last_reset_type
+                ): validate_last_reset_type
+            }
         )
     return schema
 
 
 @FILTER_REGISTRY.register("offset", OffsetFilter, cv.float_)
-def offset_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(filter_id, config)
+async def offset_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(filter_id, config)
 
 
 @FILTER_REGISTRY.register("multiply", MultiplyFilter, cv.float_)
-def multiply_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(filter_id, config)
+async def multiply_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(filter_id, config)
 
 
 @FILTER_REGISTRY.register("filter_out", FilterOutValueFilter, cv.float_)
-def filter_out_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(filter_id, config)
+async def filter_out_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(filter_id, config)
 
 
 MEDIAN_SCHEMA = cv.All(
@@ -241,8 +292,8 @@ MEDIAN_SCHEMA = cv.All(
 
 
 @FILTER_REGISTRY.register("median", MedianFilter, MEDIAN_SCHEMA)
-def median_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(
+async def median_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(
         filter_id,
         config[CONF_WINDOW_SIZE],
         config[CONF_SEND_EVERY],
@@ -263,8 +314,8 @@ MIN_SCHEMA = cv.All(
 
 
 @FILTER_REGISTRY.register("min", MinFilter, MIN_SCHEMA)
-def min_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(
+async def min_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(
         filter_id,
         config[CONF_WINDOW_SIZE],
         config[CONF_SEND_EVERY],
@@ -285,8 +336,8 @@ MAX_SCHEMA = cv.All(
 
 
 @FILTER_REGISTRY.register("max", MaxFilter, MAX_SCHEMA)
-def max_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(
+async def max_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(
         filter_id,
         config[CONF_WINDOW_SIZE],
         config[CONF_SEND_EVERY],
@@ -311,8 +362,8 @@ SLIDING_AVERAGE_SCHEMA = cv.All(
     SlidingWindowMovingAverageFilter,
     SLIDING_AVERAGE_SCHEMA,
 )
-def sliding_window_moving_average_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(
+async def sliding_window_moving_average_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(
         filter_id,
         config[CONF_WINDOW_SIZE],
         config[CONF_SEND_EVERY],
@@ -330,52 +381,52 @@ def sliding_window_moving_average_filter_to_code(config, filter_id):
         }
     ),
 )
-def exponential_moving_average_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(filter_id, config[CONF_ALPHA], config[CONF_SEND_EVERY])
+async def exponential_moving_average_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(filter_id, config[CONF_ALPHA], config[CONF_SEND_EVERY])
 
 
 @FILTER_REGISTRY.register("lambda", LambdaFilter, cv.returning_lambda)
-def lambda_filter_to_code(config, filter_id):
-    lambda_ = yield cg.process_lambda(
+async def lambda_filter_to_code(config, filter_id):
+    lambda_ = await cg.process_lambda(
         config, [(float, "x")], return_type=cg.optional.template(float)
     )
-    yield cg.new_Pvariable(filter_id, lambda_)
+    return cg.new_Pvariable(filter_id, lambda_)
 
 
 @FILTER_REGISTRY.register("delta", DeltaFilter, cv.float_)
-def delta_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(filter_id, config)
+async def delta_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(filter_id, config)
 
 
 @FILTER_REGISTRY.register("or", OrFilter, validate_filters)
-def or_filter_to_code(config, filter_id):
-    filters = yield build_filters(config)
-    yield cg.new_Pvariable(filter_id, filters)
+async def or_filter_to_code(config, filter_id):
+    filters = await build_filters(config)
+    return cg.new_Pvariable(filter_id, filters)
 
 
 @FILTER_REGISTRY.register(
     "throttle", ThrottleFilter, cv.positive_time_period_milliseconds
 )
-def throttle_filter_to_code(config, filter_id):
-    yield cg.new_Pvariable(filter_id, config)
+async def throttle_filter_to_code(config, filter_id):
+    return cg.new_Pvariable(filter_id, config)
 
 
 @FILTER_REGISTRY.register(
     "heartbeat", HeartbeatFilter, cv.positive_time_period_milliseconds
 )
-def heartbeat_filter_to_code(config, filter_id):
+async def heartbeat_filter_to_code(config, filter_id):
     var = cg.new_Pvariable(filter_id, config)
-    yield cg.register_component(var, {})
-    yield var
+    await cg.register_component(var, {})
+    return var
 
 
 @FILTER_REGISTRY.register(
     "debounce", DebounceFilter, cv.positive_time_period_milliseconds
 )
-def debounce_filter_to_code(config, filter_id):
+async def debounce_filter_to_code(config, filter_id):
     var = cg.new_Pvariable(filter_id, config)
-    yield cg.register_component(var, {})
-    yield var
+    await cg.register_component(var, {})
+    return var
 
 
 def validate_not_all_from_same(config):
@@ -394,11 +445,11 @@ def validate_not_all_from_same(config):
         cv.ensure_list(validate_datapoint), cv.Length(min=2), validate_not_all_from_same
     ),
 )
-def calibrate_linear_filter_to_code(config, filter_id):
+async def calibrate_linear_filter_to_code(config, filter_id):
     x = [conf[CONF_FROM] for conf in config]
     y = [conf[CONF_TO] for conf in config]
     k, b = fit_linear(x, y)
-    yield cg.new_Pvariable(filter_id, k, b)
+    return cg.new_Pvariable(filter_id, k, b)
 
 
 CONF_DATAPOINTS = "datapoints"
@@ -430,7 +481,7 @@ def validate_calibrate_polynomial(config):
         validate_calibrate_polynomial,
     ),
 )
-def calibrate_polynomial_filter_to_code(config, filter_id):
+async def calibrate_polynomial_filter_to_code(config, filter_id):
     x = [conf[CONF_FROM] for conf in config[CONF_DATAPOINTS]]
     y = [conf[CONF_TO] for conf in config[CONF_DATAPOINTS]]
     degree = config[CONF_DEGREE]
@@ -438,52 +489,55 @@ def calibrate_polynomial_filter_to_code(config, filter_id):
     # Column vector
     b = [[v] for v in y]
     res = [v[0] for v in _lstsq(a, b)]
-    yield cg.new_Pvariable(filter_id, res)
+    return cg.new_Pvariable(filter_id, res)
 
 
-@coroutine
-def build_filters(config):
-    yield cg.build_registry_list(FILTER_REGISTRY, config)
+async def build_filters(config):
+    return await cg.build_registry_list(FILTER_REGISTRY, config)
 
 
-@coroutine
-def setup_sensor_core_(var, config):
+async def setup_sensor_core_(var, config):
     cg.add(var.set_name(config[CONF_NAME]))
+    cg.add(var.set_disabled_by_default(config[CONF_DISABLED_BY_DEFAULT]))
     if CONF_INTERNAL in config:
         cg.add(var.set_internal(config[CONF_INTERNAL]))
     if CONF_DEVICE_CLASS in config:
         cg.add(var.set_device_class(config[CONF_DEVICE_CLASS]))
+    if CONF_STATE_CLASS in config:
+        cg.add(var.set_state_class(config[CONF_STATE_CLASS]))
     if CONF_UNIT_OF_MEASUREMENT in config:
         cg.add(var.set_unit_of_measurement(config[CONF_UNIT_OF_MEASUREMENT]))
     if CONF_ICON in config:
         cg.add(var.set_icon(config[CONF_ICON]))
     if CONF_ACCURACY_DECIMALS in config:
         cg.add(var.set_accuracy_decimals(config[CONF_ACCURACY_DECIMALS]))
+    if CONF_LAST_RESET_TYPE in config:
+        cg.add(var.set_last_reset_type(config[CONF_LAST_RESET_TYPE]))
     cg.add(var.set_force_update(config[CONF_FORCE_UPDATE]))
     if config.get(CONF_FILTERS):  # must exist and not be empty
-        filters = yield build_filters(config[CONF_FILTERS])
+        filters = await build_filters(config[CONF_FILTERS])
         cg.add(var.set_filters(filters))
 
     for conf in config.get(CONF_ON_VALUE, []):
         trigger = cg.new_Pvariable(conf[CONF_TRIGGER_ID], var)
-        yield automation.build_automation(trigger, [(float, "x")], conf)
+        await automation.build_automation(trigger, [(float, "x")], conf)
     for conf in config.get(CONF_ON_RAW_VALUE, []):
         trigger = cg.new_Pvariable(conf[CONF_TRIGGER_ID], var)
-        yield automation.build_automation(trigger, [(float, "x")], conf)
+        await automation.build_automation(trigger, [(float, "x")], conf)
     for conf in config.get(CONF_ON_VALUE_RANGE, []):
         trigger = cg.new_Pvariable(conf[CONF_TRIGGER_ID], var)
-        yield cg.register_component(trigger, conf)
+        await cg.register_component(trigger, conf)
         if CONF_ABOVE in conf:
-            template_ = yield cg.templatable(conf[CONF_ABOVE], [(float, "x")], float)
+            template_ = await cg.templatable(conf[CONF_ABOVE], [(float, "x")], float)
             cg.add(trigger.set_min(template_))
         if CONF_BELOW in conf:
-            template_ = yield cg.templatable(conf[CONF_BELOW], [(float, "x")], float)
+            template_ = await cg.templatable(conf[CONF_BELOW], [(float, "x")], float)
             cg.add(trigger.set_max(template_))
-        yield automation.build_automation(trigger, [(float, "x")], conf)
+        await automation.build_automation(trigger, [(float, "x")], conf)
 
     if CONF_MQTT_ID in config:
         mqtt_ = cg.new_Pvariable(config[CONF_MQTT_ID], var)
-        yield mqtt.register_mqtt_component(mqtt_, config)
+        await mqtt.register_mqtt_component(mqtt_, config)
 
         if CONF_EXPIRE_AFTER in config:
             if config[CONF_EXPIRE_AFTER] is None:
@@ -492,19 +546,17 @@ def setup_sensor_core_(var, config):
                 cg.add(mqtt_.set_expire_after(config[CONF_EXPIRE_AFTER]))
 
 
-@coroutine
-def register_sensor(var, config):
+async def register_sensor(var, config):
     if not CORE.has_id(config[CONF_ID]):
         var = cg.Pvariable(config[CONF_ID], var)
     cg.add(cg.App.register_sensor(var))
-    yield setup_sensor_core_(var, config)
+    await setup_sensor_core_(var, config)
 
 
-@coroutine
-def new_sensor(config):
+async def new_sensor(config):
     var = cg.new_Pvariable(config[CONF_ID])
-    yield register_sensor(var, config)
-    yield var
+    await register_sensor(var, config)
+    return var
 
 
 SENSOR_IN_RANGE_CONDITION_SCHEMA = cv.All(
@@ -520,8 +572,8 @@ SENSOR_IN_RANGE_CONDITION_SCHEMA = cv.All(
 @automation.register_condition(
     "sensor.in_range", SensorInRangeCondition, SENSOR_IN_RANGE_CONDITION_SCHEMA
 )
-def sensor_in_range_to_code(config, condition_id, template_arg, args):
-    paren = yield cg.get_variable(config[CONF_ID])
+async def sensor_in_range_to_code(config, condition_id, template_arg, args):
+    paren = await cg.get_variable(config[CONF_ID])
     var = cg.new_Pvariable(condition_id, template_arg, paren)
 
     if CONF_ABOVE in config:
@@ -529,7 +581,7 @@ def sensor_in_range_to_code(config, condition_id, template_arg, args):
     if CONF_BELOW in config:
         cg.add(var.set_max(config[CONF_BELOW]))
 
-    yield var
+    return var
 
 
 def _mean(xs):
@@ -618,6 +670,6 @@ def _lstsq(a, b):
 
 
 @coroutine_with_priority(40.0)
-def to_code(config):
+async def to_code(config):
     cg.add_define("USE_SENSOR")
     cg.add_global(sensor_ns.using)
