@@ -4,18 +4,32 @@
 namespace esphome {
 namespace sensor {
 
-static const char *TAG = "sensor";
+static const char *const TAG = "sensor";
 
 const char *state_class_to_string(StateClass state_class) {
   switch (state_class) {
     case STATE_CLASS_MEASUREMENT:
       return "measurement";
+    case STATE_CLASS_TOTAL_INCREASING:
+      return "total_increasing";
     case STATE_CLASS_NONE:
     default:
       return "";
   }
 }
 
+const char *last_reset_type_to_string(LastResetType last_reset_type) {
+  switch (last_reset_type) {
+    case LAST_RESET_TYPE_NEVER:
+      return "never";
+    case LAST_RESET_TYPE_AUTO:
+      return "auto";
+    case LAST_RESET_TYPE_NONE:
+    default:
+      return "";
+  }
+}
+
 void Sensor::publish_state(float state) {
   this->raw_state = state;
   this->raw_callback_.call(state);
@@ -28,7 +42,6 @@ void Sensor::publish_state(float state) {
     this->filter_list_->input(state);
   }
 }
-void Sensor::push_new_value(float state) { this->publish_state(state); }
 std::string Sensor::unit_of_measurement() { return ""; }
 std::string Sensor::icon() { return ""; }
 uint32_t Sensor::update_interval() { return 0; }
@@ -61,10 +74,13 @@ void Sensor::set_state_class(StateClass state_class) { this->state_class = state
 void Sensor::set_state_class(const std::string &state_class) {
   if (str_equals_case_insensitive(state_class, "measurement")) {
     this->state_class = STATE_CLASS_MEASUREMENT;
+  } else if (str_equals_case_insensitive(state_class, "total_increasing")) {
+    this->state_class = STATE_CLASS_TOTAL_INCREASING;
   } else {
     ESP_LOGW(TAG, "'%s' - Unrecognized state class %s", this->get_name().c_str(), state_class.c_str());
   }
 }
+void Sensor::set_last_reset_type(LastResetType last_reset_type) { this->last_reset_type = last_reset_type; }
 std::string Sensor::get_unit_of_measurement() {
   if (this->unit_of_measurement_.has_value())
     return *this->unit_of_measurement_;
@@ -104,9 +120,7 @@ void Sensor::clear_filters() {
   }
   this->filter_list_ = nullptr;
 }
-float Sensor::get_value() const { return this->state; }
 float Sensor::get_state() const { return this->state; }
-float Sensor::get_raw_value() const { return this->raw_state; }
 float Sensor::get_raw_state() const { return this->raw_state; }
 std::string Sensor::unique_id() { return ""; }
 
