@@ -8,6 +8,11 @@
 #include "sntp.h"
 #endif
 
+// Yes, the server names are leaked, but that's fine.
+#ifdef CLANG_TIDY
+#define strdup(x) (const_cast<char *>(x))
+#endif
+
 namespace esphome {
 namespace sntp {
 
