@@ -1,5 +1,6 @@
 #pragma once
 
+#include <vector>
 #include <HardwareSerial.h>
 #include "esphome/core/esphal.h"
 #include "esphome/core/component.h"
@@ -7,10 +8,19 @@
 namespace esphome {
 namespace uart {
 
+enum UARTParityOptions {
+  UART_CONFIG_PARITY_NONE,
+  UART_CONFIG_PARITY_EVEN,
+  UART_CONFIG_PARITY_ODD,
+};
+
+const char *parity_to_str(UARTParityOptions parity);
+
 #ifdef ARDUINO_ARCH_ESP8266
 class ESP8266SoftwareSerial {
  public:
-  void setup(int8_t tx_pin, int8_t rx_pin, uint32_t baud_rate, uint8_t stop_bits);
+  void setup(int8_t tx_pin, int8_t rx_pin, uint32_t baud_rate, uint8_t stop_bits, uint32_t data_bits,
+             UARTParityOptions parity, size_t rx_buffer_size);
 
   uint8_t read_byte();
   uint8_t peek_byte();
@@ -21,6 +31,9 @@ class ESP8266SoftwareSerial {
 
   int available();
 
+  GPIOPin *gpio_tx_pin_{nullptr};
+  GPIOPin *gpio_rx_pin_{nullptr};
+
  protected:
   static void gpio_intr(ESP8266SoftwareSerial *arg);
 
@@ -30,10 +43,12 @@ class ESP8266SoftwareSerial {
 
   uint32_t bit_time_{0};
   uint8_t *rx_buffer_{nullptr};
-  size_t rx_buffer_size_{512};
+  size_t rx_buffer_size_;
   volatile size_t rx_in_pos_{0};
   size_t rx_out_pos_{0};
   uint8_t stop_bits_;
+  uint8_t data_bits_;
+  UARTParityOptions parity_;
   ISRInternalGPIOPin *tx_pin_{nullptr};
   ISRInternalGPIOPin *rx_pin_{nullptr};
 };
@@ -42,6 +57,9 @@ class ESP8266SoftwareSerial {
 class UARTComponent : public Component, public Stream {
  public:
   void set_baud_rate(uint32_t baud_rate) { baud_rate_ = baud_rate; }
+  uint32_t get_baud_rate() const { return baud_rate_; }
+
+  uint32_t get_config();
 
   void setup() override;
 
@@ -73,7 +91,13 @@ class UARTComponent : public Component, public Stream {
 
   void set_tx_pin(uint8_t tx_pin) { this->tx_pin_ = tx_pin; }
   void set_rx_pin(uint8_t rx_pin) { this->rx_pin_ = rx_pin; }
+  void set_rx_buffer_size(size_t rx_buffer_size) { this->rx_buffer_size_ = rx_buffer_size; }
+#ifdef ARDUINO_ARCH_ESP32
+  void set_invert(bool invert) { this->invert_ = invert; }
+#endif
   void set_stop_bits(uint8_t stop_bits) { this->stop_bits_ = stop_bits; }
+  void set_data_bits(uint8_t data_bits) { this->data_bits_ = data_bits; }
+  void set_parity(UARTParityOptions parity) { this->parity_ = parity; }
 
  protected:
   void check_logger_conflict_();
@@ -86,8 +110,14 @@ class UARTComponent : public Component, public Stream {
 #endif
   optional<uint8_t> tx_pin_;
   optional<uint8_t> rx_pin_;
+  size_t rx_buffer_size_;
+#ifdef ARDUINO_ARCH_ESP32
+  bool invert_;
+#endif
   uint32_t baud_rate_;
   uint8_t stop_bits_;
+  uint8_t data_bits_;
+  UARTParityOptions parity_;
 };
 
 #ifdef ARDUINO_ARCH_ESP32
@@ -132,7 +162,8 @@ class UARTDevice : public Stream {
   int peek() override { return this->parent_->peek(); }
 
   /// Check that the configuration of the UART bus matches the provided values and otherwise print a warning
-  void check_uart_settings(uint32_t baud_rate, uint8_t stop_bits = 1);
+  void check_uart_settings(uint32_t baud_rate, uint8_t stop_bits = 1,
+                           UARTParityOptions parity = UART_CONFIG_PARITY_NONE, uint8_t data_bits = 8);
 
  protected:
   UARTComponent *parent_{nullptr};
