@@ -1,6 +1,6 @@
 """Constants used by esphome."""
 
-__version__ = "1.20.4"
+__version__ = "2021.8.0"
 
 ESP_PLATFORM_ESP32 = "ESP32"
 ESP_PLATFORM_ESP8266 = "ESP8266"
@@ -24,6 +24,7 @@ ARDUINO_VERSION_ESP32 = {
 # See also https://github.com/platformio/platform-espressif8266/releases
 ARDUINO_VERSION_ESP8266 = {
     "dev": "https://github.com/platformio/platform-espressif8266.git",
+    "3.0.1": "platformio/espressif8266@3.1.0",
     "3.0.0": "platformio/espressif8266@3.0.0",
     "2.7.4": "platformio/espressif8266@2.6.2",
     "2.7.3": "platformio/espressif8266@2.6.1",
@@ -95,6 +96,7 @@ CONF_BUFFER_SIZE = "buffer_size"
 CONF_BUILD_PATH = "build_path"
 CONF_BUS_VOLTAGE = "bus_voltage"
 CONF_BUSY_PIN = "busy_pin"
+CONF_CALCULATED_LUX = "calculated_lux"
 CONF_CALIBRATE_LINEAR = "calibrate_linear"
 CONF_CALIBRATION = "calibration"
 CONF_CAPACITANCE = "capacitance"
@@ -120,6 +122,7 @@ CONF_COLD_WHITE_COLOR_TEMPERATURE = "cold_white_color_temperature"
 CONF_COLOR = "color"
 CONF_COLOR_BRIGHTNESS = "color_brightness"
 CONF_COLOR_CORRECT = "color_correct"
+CONF_COLOR_MODE = "color_mode"
 CONF_COLOR_TEMPERATURE = "color_temperature"
 CONF_COLORS = "colors"
 CONF_COMMAND = "command"
@@ -131,9 +134,12 @@ CONF_COMPONENTS = "components"
 CONF_CONDITION = "condition"
 CONF_CONDITION_ID = "condition_id"
 CONF_CONDUCTIVITY = "conductivity"
+CONF_CONSTANT_BRIGHTNESS = "constant_brightness"
 CONF_CONTRAST = "contrast"
 CONF_COOL_ACTION = "cool_action"
+CONF_COOL_DEADBAND = "cool_deadband"
 CONF_COOL_MODE = "cool_mode"
+CONF_COOL_OVERRUN = "cool_overrun"
 CONF_COUNT = "count"
 CONF_COUNT_MODE = "count_mode"
 CONF_COURSE = "course"
@@ -157,8 +163,10 @@ CONF_DATA_TEMPLATE = "data_template"
 CONF_DAYS_OF_MONTH = "days_of_month"
 CONF_DAYS_OF_WEEK = "days_of_week"
 CONF_DC_PIN = "dc_pin"
+CONF_DEASSERT_RTS_DTR = "deassert_rts_dtr"
 CONF_DEBOUNCE = "debounce"
 CONF_DECELERATION = "deceleration"
+CONF_DEFAULT_MODE = "default_mode"
 CONF_DEFAULT_TARGET_TEMPERATURE_HIGH = "default_target_temperature_high"
 CONF_DEFAULT_TARGET_TEMPERATURE_LOW = "default_target_temperature_low"
 CONF_DEFAULT_TRANSITION_LENGTH = "default_transition_length"
@@ -166,11 +174,13 @@ CONF_DELAY = "delay"
 CONF_DELTA = "delta"
 CONF_DEVICE = "device"
 CONF_DEVICE_CLASS = "device_class"
+CONF_DEVICE_FACTOR = "device_factor"
 CONF_DIMENSIONS = "dimensions"
 CONF_DIO_PIN = "dio_pin"
 CONF_DIR_PIN = "dir_pin"
 CONF_DIRECTION = "direction"
 CONF_DIRECTION_OUTPUT = "direction_output"
+CONF_DISABLED_BY_DEFAULT = "disabled_by_default"
 CONF_DISCOVERY = "discovery"
 CONF_DISCOVERY_PREFIX = "discovery_prefix"
 CONF_DISCOVERY_RETAIN = "discovery_retain"
@@ -217,7 +227,11 @@ CONF_FAN_MODE_MIDDLE_ACTION = "fan_mode_middle_action"
 CONF_FAN_MODE_OFF_ACTION = "fan_mode_off_action"
 CONF_FAN_MODE_ON_ACTION = "fan_mode_on_action"
 CONF_FAN_ONLY_ACTION = "fan_only_action"
+CONF_FAN_ONLY_ACTION_USES_FAN_MODE_TIMER = "fan_only_action_uses_fan_mode_timer"
+CONF_FAN_ONLY_COOLING = "fan_only_cooling"
 CONF_FAN_ONLY_MODE = "fan_only_mode"
+CONF_FAN_WITH_COOLING = "fan_with_cooling"
+CONF_FAN_WITH_HEATING = "fan_with_heating"
 CONF_FAST_CONNECT = "fast_connect"
 CONF_FILE = "file"
 CONF_FILTER = "filter"
@@ -234,11 +248,13 @@ CONF_FORMAT = "format"
 CONF_FORWARD_ACTIVE_ENERGY = "forward_active_energy"
 CONF_FREQUENCY = "frequency"
 CONF_FROM = "from"
+CONF_FULL_SPECTRUM = "full_spectrum"
 CONF_FULL_UPDATE_EVERY = "full_update_every"
 CONF_GAIN = "gain"
 CONF_GAMMA_CORRECT = "gamma_correct"
 CONF_GAS_RESISTANCE = "gas_resistance"
 CONF_GATEWAY = "gateway"
+CONF_GLASS_ATTENUATION_FACTOR = "glass_attenuation_factor"
 CONF_GLYPHS = "glyphs"
 CONF_GPIO = "gpio"
 CONF_GREEN = "green"
@@ -246,7 +262,9 @@ CONF_GROUP = "group"
 CONF_HARDWARE_UART = "hardware_uart"
 CONF_HEARTBEAT = "heartbeat"
 CONF_HEAT_ACTION = "heat_action"
+CONF_HEAT_DEADBAND = "heat_deadband"
 CONF_HEAT_MODE = "heat_mode"
+CONF_HEAT_OVERRUN = "heat_overrun"
 CONF_HEATER = "heater"
 CONF_HEIGHT = "height"
 CONF_HIDDEN = "hidden"
@@ -275,7 +293,9 @@ CONF_IMPORT_REACTIVE_ENERGY = "import_reactive_energy"
 CONF_INCLUDES = "includes"
 CONF_INDEX = "index"
 CONF_INDOOR = "indoor"
+CONF_INFRARED = "infrared"
 CONF_INITIAL_MODE = "initial_mode"
+CONF_INITIAL_OPTION = "initial_option"
 CONF_INITIAL_VALUE = "initial_value"
 CONF_INTEGRATION_TIME = "integration_time"
 CONF_INTENSITY = "intensity"
@@ -320,8 +340,10 @@ CONF_MAKE_ID = "make_id"
 CONF_MANUAL_IP = "manual_ip"
 CONF_MANUFACTURER_ID = "manufacturer_id"
 CONF_MASK_DISTURBER = "mask_disturber"
+CONF_MAX_COOLING_RUN_TIME = "max_cooling_run_time"
 CONF_MAX_CURRENT = "max_current"
 CONF_MAX_DURATION = "max_duration"
+CONF_MAX_HEATING_RUN_TIME = "max_heating_run_time"
 CONF_MAX_LENGTH = "max_length"
 CONF_MAX_LEVEL = "max_level"
 CONF_MAX_POWER = "max_power"
@@ -335,6 +357,14 @@ CONF_MEASUREMENT_SEQUENCE_NUMBER = "measurement_sequence_number"
 CONF_MEDIUM = "medium"
 CONF_MEMORY_BLOCKS = "memory_blocks"
 CONF_METHOD = "method"
+CONF_MIN_COOLING_OFF_TIME = "min_cooling_off_time"
+CONF_MIN_COOLING_RUN_TIME = "min_cooling_run_time"
+CONF_MIN_FAN_MODE_SWITCHING_TIME = "min_fan_mode_switching_time"
+CONF_MIN_FANNING_OFF_TIME = "min_fanning_off_time"
+CONF_MIN_FANNING_RUN_TIME = "min_fanning_run_time"
+CONF_MIN_HEATING_OFF_TIME = "min_heating_off_time"
+CONF_MIN_HEATING_RUN_TIME = "min_heating_run_time"
+CONF_MIN_IDLE_TIME = "min_idle_time"
 CONF_MIN_LENGTH = "min_length"
 CONF_MIN_LEVEL = "min_level"
 CONF_MIN_POWER = "min_power"
@@ -405,6 +435,8 @@ CONF_OPEN_DRAIN_INTERRUPT = "open_drain_interrupt"
 CONF_OPEN_DURATION = "open_duration"
 CONF_OPEN_ENDSTOP = "open_endstop"
 CONF_OPTIMISTIC = "optimistic"
+CONF_OPTION = "option"
+CONF_OPTIONS = "options"
 CONF_OR = "or"
 CONF_OSCILLATING = "oscillating"
 CONF_OSCILLATION_COMMAND_TOPIC = "oscillation_command_topic"
@@ -436,10 +468,19 @@ CONF_PINS = "pins"
 CONF_PIXEL_MAPPER = "pixel_mapper"
 CONF_PLATFORM = "platform"
 CONF_PLATFORMIO_OPTIONS = "platformio_options"
+CONF_PM_0_3UM = "pm_0_3um"
+CONF_PM_0_5UM = "pm_0_5um"
 CONF_PM_1_0 = "pm_1_0"
+CONF_PM_1_0_STD = "pm_1_0_std"
+CONF_PM_1_0UM = "pm_1_0um"
 CONF_PM_10_0 = "pm_10_0"
+CONF_PM_10_0_STD = "pm_10_0_std"
+CONF_PM_10_0UM = "pm_10_0um"
 CONF_PM_2_5 = "pm_2_5"
+CONF_PM_2_5_STD = "pm_2_5_std"
+CONF_PM_2_5UM = "pm_2_5um"
 CONF_PM_4_0 = "pm_4_0"
+CONF_PM_5_0UM = "pm_5_0um"
 CONF_PM_SIZE = "pm_size"
 CONF_PMC_0_5 = "pmc_0_5"
 CONF_PMC_1_0 = "pmc_1_0"
@@ -527,6 +568,7 @@ CONF_SERVERS = "servers"
 CONF_SERVICE = "service"
 CONF_SERVICE_UUID = "service_uuid"
 CONF_SERVICES = "services"
+CONF_SET_POINT_MINIMUM_DIFFERENTIAL = "set_point_minimum_differential"
 CONF_SETUP_MODE = "setup_mode"
 CONF_SETUP_PRIORITY = "setup_priority"
 CONF_SHUNT_RESISTANCE = "shunt_resistance"
@@ -546,6 +588,7 @@ CONF_SPI_ID = "spi_id"
 CONF_SPIKE_REJECTION = "spike_rejection"
 CONF_SSID = "ssid"
 CONF_SSL_FINGERPRINTS = "ssl_fingerprints"
+CONF_STARTUP_DELAY = "startup_delay"
 CONF_STATE = "state"
 CONF_STATE_CLASS = "state_class"
 CONF_STATE_TOPIC = "state_topic"
@@ -558,6 +601,10 @@ CONF_STOP = "stop"
 CONF_STOP_ACTION = "stop_action"
 CONF_SUBNET = "subnet"
 CONF_SUBSTITUTIONS = "substitutions"
+CONF_SUPPLEMENTAL_COOLING_ACTION = "supplemental_cooling_action"
+CONF_SUPPLEMENTAL_COOLING_DELTA = "supplemental_cooling_delta"
+CONF_SUPPLEMENTAL_HEATING_ACTION = "supplemental_heating_action"
+CONF_SUPPLEMENTAL_HEATING_DELTA = "supplemental_heating_delta"
 CONF_SUPPORTS_COOL = "supports_cool"
 CONF_SUPPORTS_HEAT = "supports_heat"
 CONF_SWING_BOTH_ACTION = "swing_both_action"
@@ -572,6 +619,7 @@ CONF_TABLET = "tablet"
 CONF_TAG = "tag"
 CONF_TARGET = "target"
 CONF_TARGET_TEMPERATURE = "target_temperature"
+CONF_TARGET_TEMPERATURE_CHANGE_ACTION = "target_temperature_change_action"
 CONF_TARGET_TEMPERATURE_HIGH = "target_temperature_high"
 CONF_TARGET_TEMPERATURE_LOW = "target_temperature_low"
 CONF_TEMPERATURE = "temperature"
@@ -619,6 +667,7 @@ CONF_VALUE = "value"
 CONF_VARIABLES = "variables"
 CONF_VARIANT = "variant"
 CONF_VERSION = "version"
+CONF_VISIBLE = "visible"
 CONF_VISUAL = "visual"
 CONF_VOLTAGE = "voltage"
 CONF_VOLTAGE_ATTENUATION = "voltage_attenuation"
@@ -652,8 +701,10 @@ ICON_ACCOUNT_CHECK = "mdi:account-check"
 ICON_ARROW_EXPAND_VERTICAL = "mdi:arrow-expand-vertical"
 ICON_BATTERY = "mdi:battery"
 ICON_BLUETOOTH = "mdi:bluetooth"
+ICON_BLUR = "mdi:blur"
 ICON_BRIEFCASE_DOWNLOAD = "mdi:briefcase-download"
 ICON_BRIGHTNESS_5 = "mdi:brightness-5"
+ICON_BRIGHTNESS_6 = "mdi:brightness-6"
 ICON_BUG = "mdi:bug"
 ICON_CHECK_CIRCLE_OUTLINE = "mdi:check-circle-outline"
 ICON_CHEMICAL_WEAPON = "mdi:chemical-weapon"
@@ -702,6 +753,7 @@ ICON_WIFI = "mdi:wifi"
 
 UNIT_AMPERE = "A"
 UNIT_CELSIUS = "°C"
+UNIT_COUNT_DECILITRE = "/dL"
 UNIT_COUNTS_PER_CUBIC_METER = "#/m³"
 UNIT_CUBIC_METER = "m³"
 UNIT_DECIBEL = "dB"
@@ -774,6 +826,7 @@ DEVICE_CLASS_CURRENT = "current"
 DEVICE_CLASS_ENERGY = "energy"
 DEVICE_CLASS_HUMIDITY = "humidity"
 DEVICE_CLASS_ILLUMINANCE = "illuminance"
+DEVICE_CLASS_MONETARY = "monetary"
 DEVICE_CLASS_SIGNAL_STRENGTH = "signal_strength"
 DEVICE_CLASS_TEMPERATURE = "temperature"
 DEVICE_CLASS_POWER_FACTOR = "power_factor"
@@ -787,6 +840,9 @@ STATE_CLASS_NONE = ""
 # The state represents a measurement in present time
 STATE_CLASS_MEASUREMENT = "measurement"
 
+# The state represents a total that only increases, a decrease is considered a reset.
+STATE_CLASS_TOTAL_INCREASING = "total_increasing"
+
 # This sensor does not support resetting. ie, it is not accumulative
 LAST_RESET_TYPE_NONE = ""
 # This sensor is expected to never reset its value
